package SeMeet::Controller::Auth;
use Mojo::Base 'Mojolicious::Controller', -signatures;
use YAML;

sub callback ($c) {
    my $token  = $c->oidc->get_access_token( $c->param("code") );
    my $claims = $c->oauth_claims( $token->access_token );

    my $octopus_user = $c->iapi->get('octopus/user?username=' . $claims->{preferred_username});

    my %user = (
        uuid        => $claims->{sub},
        octid       => $octopus_user->{id},
        username    => $claims->{preferred_username},
        displayname => $octopus_user->{displayname} || $claims->{name},
    );

    my $user = $c->schema->resultset('User')->search({
        -or => [
            uuid     => $claims->{sub},
            username => $claims->{preferred_username},
        ]
    })->first;

    if ( $user ) {
        $user->updata(\%user);
    }
    else {
        $user = $c->schema->resultset('User')->create(\%user);
    }

    $c->session->{user} = {
        $user->get_columns,
        token  => $user->api_token({ secret => $c->cfg->{jwt_secret}}),
    };

    my $groups = $c->schema->resultset('Group')->search(
        { octid => { '-in' => $octopus_user->{groups} }},
        { columns => ['id', 'permissions'] }
    );

    GROUP:
    while ( my $group = $groups->next ) {
        push @{$c->session->{user}{groups}}, $group->id;
        if ( $group->permissions ) {
            PERMISSION:
            foreach my $permission ( @{ $group->permissions } ) {
                $c->session->{user}{permissions}{$permission} = 1;
            }
        }
    }

    $c->authenticate();
    $c->redirect_to('/');
}

sub do_logout($c) { # nesmi se jmenovat logout - rekurze
    $c->logout;
    delete $c->session->{user};
    $c->redirect_to('/');
}

1;
